#!/bin/sh

ACTION=${1}
shift 1

get_image() {
  IMAGE_NAME="spikecodes/libreddit"
}

do_install_detail() {
  local config=`uci get libreddit.@libreddit[0].config_path 2>/dev/null`
  local port=`uci get libreddit.@libreddit[0].port 2>/dev/null`
  local IMAGE_NAME=`uci get libreddit.@libreddit[0].image_name 2>/dev/null`
  local username=`uci get libreddit.@libreddit[0].username 2>/dev/null`
  local password=`uci get libreddit.@libreddit[0].password 2>/dev/null`

  #Generate the generic environment variables for the docker-compose

  GEN_PASS=$(< /dev/urandom tr -dc A-Za-z0-9 2>/dev/null | head -c14; echo)
  GEN_PASS2=$(< /dev/urandom tr -dc A-Za-z0-9 2>/dev/null | head -c14; echo)
  
  # Get our local LAN IP Address
  LAN_IP=$(uci get network.lan.ipaddr)
  # Strip trailing network mask
  LAN_IP="${LAN_IP%/*}"
   
  if [ -z "$config" ]; then
      echo "config path is empty!"
      exit 1
  fi

  [ -z "$port" ] && port=5741
  [ -z "$IMAGE_NAME" ] && IMAGE_NAME=spikecodes/libreddit

  
  # Create Docker Compose file with custom variables
   
  # Create Docker Compose file with custom variables
touch docker-compose.yml
cat > docker-compose.yml <<EOF
version: '3.3'
services:
    libreddit:
        container_name: libreddit
        ports:
            - '$port:8080'
        restart: always
        image: spikecodes/libreddit
EOF
  
  docker-compose up -d
 
  # Add a new list option to the "shortcutmenu" configuration file
  uci add shortcutmenu lists
  uci set shortcutmenu.@lists[-1].webname="$IMAGE_NAME"
  uci set shortcutmenu.@lists[-1].weburl="$LAN_IP:$port"
  uci set shortcutmenu.@lists[-1].webpath="/"
  uci commit shortcutmenu

}

usage() {
  echo "usage: $0 sub-command"
  echo "where sub-command is one of:"
  echo "      install                Install libreddit"
  echo "      upgrade                Upgrade libreddit"
  echo "      rm/start/stop/restart  Remove/Start/Stop/Restart libreddit"
  echo "      status                 libreddit status"
  echo "      port                   libreddit port"
}

case ${ACTION} in
  "install")
    get_image
    do_install_detail
  ;;
  "upgrade")
    get_image
    do_install_detail
  ;;
  "rm")
    docker rm -f libreddit
  ;;
  "start" | "stop" | "restart")
    docker ${ACTION} libreddit
  ;;
  "status")
    docker ps --all -f 'name=libreddit' --format '{{.State}}'
  ;;
  "port")
    docker ps --all -f 'name=libreddit' --format '{{.Ports}}' | grep -om1 '0.0.0.0:[0-9]*' | sed 's/0.0.0.0://'
  ;;
  *)
    usage
    exit 1
  ;;
esac
